@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Draw fretboard chord diagrams
 
-our $VERSION = '0.0700';
+our $VERSION = '0.0701';
 
 use Moo;
 use strictures 2;
@@ -250,7 +250,7 @@ sub draw {
             text  => $chord_name,
             color => $BLACK,
             x     => $SPACE,
-            y     => $SPACE + $self->frets * $SPACE - $self->frets - $SPACE / 4,
+            y     => $self->strings * $SPACE - $SPACE / 3,
             size  => $SPACE / 2,
             aa    => 1,
         );
@@ -383,7 +383,7 @@ sub _draw_horiz {
             text  => $chord_name,
             color => $BLACK,
             x     => $SPACE,
-            y     => $SPACE * 2 + $self->frets * $SPACE - $SPACE / 3,
+            y     => ($self->strings + 1) * $SPACE - $SPACE / 3,
             size  => $SPACE / 2,
             aa    => 1,
         );
@@ -418,7 +418,7 @@ Music::FretboardDiagram - Draw fretboard chord diagrams
 
 =head1 VERSION
 
-version 0.0700
+version 0.0701
 
 =head1 SYNOPSIS
 
